PyAstronomy core (pyaC)
=========================

The **pyaC** package (pyaCore) is the place to collect functionality commonly required among PyAstronomy's subpackages.

Moreover, pyaC's documentation is the place were general guide lines for PyAstronomy are formulated. 

Functionality
---------------

.. toctree::
   :maxdepth: 1
   
   pyaErrorsDoc/index.rst
   pyaPermanentDoc/index.rst
   mtoolsDoc/mtools.rst
   needfulThings.rst

Rules and guidelines
----------------------

.. toctree::
   :maxdepth: 1
   
   versioning.rst
   IDLPorting.rst

